Gramex
======

Gramex: Visual Analytics Platform.

Gramex is a component-based building blocks approach to DataApps.

For usage instructions, see the `Gramex Guide`_.

Gramex is free for non-commercial use. Please read the `LICENSE`_.

.. _Gramex Guide: https://learn.gramener.com/guide/
.. _LICENSE: https://learn.gramener.com/guide/license/
